@@ -61,6 +61,7 @@ def build_jwk_url(strategy: str = AUTH_STRATEGY) -> str:
 def get_jwk(jwk_url) -> dict:
     try:
         r = requests.get(jwk_url)
+
         if not r.status_code == 200:
             r.raise_for_status()
 
@@ -170,12 +171,6 @@ class PassportChecker:
         JWT_PERMISSION: lambda: 1
     }
 
-    __payload__ = None
-
-    @property
-    def payload(self):
-        return self.__payload__ or {}
-
     def get_jwk_url(self) -> str:
 
         _jwk_url = self.jwk_url
@@ -207,9 +202,13 @@ class PassportChecker:
             "jwk_url": self.jwk_url
         })
 
-        self.__payload__ = _strategy_callable(token, **self.strategy_kwargs)
+        _strategy_callable(token, **self.strategy_kwargs)
 
-        return self.payload
+        return {
+            "is_valid": True,
+            "message": "Token seems valid",
+            "token": self.token
+        }
 
     def __post_init__(self):
         if self.auto_init:
